Diophantine approximation
=========================

The diophantine approximation deals with the approximation of real numbers
(or real vectors) with rational numbers (or rational vectors).
See the article :wikipedia:`Diophantine_approximation` for more information.

.. toctree::
   :maxdepth: 1

   sage/rings/continued_fraction

.. include:: ../footer.txt
